BASE_URL = "https://apis.apigle.com"

ENDPOINTS = {
    "search_v1": "/v1/search",
    "search_v2": "/v2/search",
    "download": "/v2/download",
    "downloadstr": "/v2/downloadstr",
    "video_comments": "/v2/videoComments",
    "video_details": "/v2/videoDetails",
    "channel_details": "/v2/channelDetails",
    "channel_videos": "/v2/channelVideos",
    "playlist_details": "/v2/playlistDetails",
    "playlist_videos": "/v2/playlistVideos",
    "trending": "/v2/trending",
    "video_categories": "/v2/videoCategories",
    "i18n_regions": "/v2/i18nRegions",
}



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()
 
setup(
    name='apigle',
    version='1.0.2',
    description='Official Python client for Apigle.com API',
    long_description=long_description,
    long_description_content_type="text/markdown",  # Bu önemli!
    url="https://github.com/boztek/apigle-python",
    author='Boztek LTD',
    packages=find_packages(),
    install_requires=[
        'requests',
    ],
    python_requires='>=3.7',
)
